@@ -5,7 +5,6 @@ function check_result() {
         echo "[+] Success."
     else
         echo "[!] Failed."
-        exit 1
     fi
 }
 
@@ -31,15 +30,15 @@ ffmpeg -version 2>&1
 # Version
 echo "[i] Version:"
 lebiniou --version
-check_result version
+check_result
 # Help
 echo "[i] Help:"
 lebiniou -q --help
-check_result help
+check_result
 # Statistics
 echo "[i] Statistics:"
 lebiniou -q -i twip -o NULL --stats
-check_result stats
+check_result
 # First video
 export LEBINIOU_MP4_FILENAME=$AUTOPKGTEST_TMP/video1.mp4
 echo -n "[i] Encoding video #1... "
@@ -58,7 +57,7 @@ sha256sum $AUTOPKGTEST_TMP/video1.log
 echo -n "    * video2.log: "
 sha256sum $AUTOPKGTEST_TMP/video2.log
 diff $AUTOPKGTEST_TMP/video1.log $AUTOPKGTEST_TMP/video2.log
-check_result logs
+check_result
 echo "[i] Extracting per-packet SHA256 hashes:"
 echo -n "    * video1.mp4... "
 ffmpeg -loglevel quiet -i $AUTOPKGTEST_TMP/video1.mp4 -f framehash - | grep -v " 1," > $AUTOPKGTEST_TMP/out1.sha256
@@ -70,4 +69,4 @@ echo "[i] Generated hashes:"
 ls -lh $AUTOPKGTEST_TMP/*.sha256
 echo "[i] Comparing per-packet hashes:"
 diff $AUTOPKGTEST_TMP/out1.sha256 $AUTOPKGTEST_TMP/out2.sha256
-check_result sha256
+check_result
